@@ -6,8 +6,7 @@ from tzlocal import get_localzone
 import getpass as gp
 import keyring
 import pytz
-try: import simplejson as json
-except ImportError: import json
+import json
 if "win32" in sys.platform:
     import colorama
     colorama.init()
@@ -66,6 +65,10 @@ def u(s):
     """Mock unicode function for python 2 and 3 compatibility."""
     return s if PY3 or type(s) is unicode else unicode(s.encode('string-escape'), "unicode_escape")
 
+def py2encode(s):
+    """Encode in Python 2, but not in python 3."""
+    return s.encode("utf-8") if PY2 and type(s) is unicode else s
+
 def prompt(msg):
     """Prints a message to the std err stream defined in util."""
     if not msg.endswith("\n"):
